from typing import Literal

from nagiosplugin.result import Results

class Summary:
    def ok(self, results: Results) -> str: ...
    def problem(self, results: Results) -> str: ...
    def verbose(self, results: Results) -> list[str]: ...
    def empty(self) -> Literal["no check results"]: ...
